@@ -60,7 +60,7 @@ static GList *		gb_xbel_extensions 		(GbIO *io);
 static GbBookmarkSet *	xbel_read			(xmlDocPtr item);
 static GbBookmark *	xbel_read_node 			(GbBookmarkSet *set, xmlNodePtr node);
 
-static xmlNodePtr	get_child 			(xmlNodePtr parent, const gchar *name);
+static xmlNodePtr	get_child 			(xmlNodePtr parent, const xmlChar *name);
 static gchar *		get_child_value_string		(xmlNodePtr parent, const gchar *name);
 static gboolean		get_child_value_boolean		(xmlNodePtr parent, const gchar *name);
 static glong		get_child_value_long		(xmlNodePtr parent, const gchar *name);
@@ -256,7 +256,7 @@ gb_xbel_save_to_string (GbIO *io, GbBookmarkSet *set, gchar **data)
 		return FALSE;
         }
 
-	*data = mem;
+	*data = (gchar*)mem;
 
 	return TRUE;
 }
@@ -290,7 +290,8 @@ xbel_read (xmlDocPtr doc)
 	xmlNodePtr item = doc->children;	
 
 	/* FIXME: very hacky */
-	while (!(item->children && !strcmp (item->name, "xbel"))  && item->next)
+	while (!(item->children && !strcmp ((char*)item->name, "xbel"))  &&
+               item->next)
 	{
 		item = item->next;
 	}
@@ -331,12 +332,12 @@ xbel_read_node (GbBookmarkSet *set, xmlNodePtr node)
 		/*  Unknown node */
 		g_warning ("xml node with NULL name!");
 	} 
-	else if (!strcmp (node->name, "folder")
-		 || !strcmp (node->name, "xbel")) 
+	else if (!strcmp ((char*)node->name, "folder")
+		 || !strcmp ((char*)node->name, "xbel")) 
 	{
 		GbFolder *folder;
 		gchar *title = get_child_value_string (node, "title");
-		gchar *folded_s = xmlGetProp (node, "folded");
+		gchar *folded_s = (gchar*)xmlGetProp (node, (const xmlChar*)"folded");
 		gboolean folded = FALSE;
 		if (folded_s
 		    && (!g_ascii_strcasecmp (folded_s, "yes") 
@@ -350,13 +351,13 @@ xbel_read_node (GbBookmarkSet *set, xmlNodePtr node)
 
 		if (!title)
 		{
-			xmlNodePtr tn = get_child (node, "title");
+			xmlNodePtr tn = get_child (node, (const xmlChar*)"title");
 			if (tn != NULL) /* it was present */
 				title = g_strdup ("");
 		}
 		if (!title) 
 		{
-			if (!strcmp (node->name, "xbel"))
+			if (!strcmp ((char*)node->name, "xbel"))
 				title = g_strdup (_("XBEL bookmarks root"));
 			else
 				title = g_strdup (_("Untitled folder"));
@@ -411,7 +412,7 @@ xbel_read_node (GbBookmarkSet *set, xmlNodePtr node)
 		
 		g_free (title);
 
-		if (set->root == NULL && !strcmp (node->name, "xbel"))
+		if (set->root == NULL && !strcmp ((char*)node->name, "xbel"))
 		{
 			gb_bookmark_set_set_root (set, folder);
 		}
@@ -443,10 +444,10 @@ xbel_read_node (GbBookmarkSet *set, xmlNodePtr node)
 		}
 
 	} 
-	else if (!strcmp (node->name, "bookmark")) 
+	else if (!strcmp ((char*)node->name, "bookmark")) 
 	{
 		gchar *title = get_child_value_string (node, "title");
-                gchar *url = xmlGetRawProp (node, "href");
+                gchar *url = (char*)xmlGetRawProp (node, (const xmlChar*)"href");
 		GbSite *site;
 		md = xbel_read_metadata (node);
 
@@ -454,7 +455,7 @@ xbel_read_node (GbBookmarkSet *set, xmlNodePtr node)
 		   or because it is "". Let's try to check it */
 		if (!title)
 		{
-			xmlNodePtr tn = get_child (node, "title");
+			xmlNodePtr tn = get_child (node, (const xmlChar*)"title");
 			if (tn != NULL) /* it was present */
 				title = g_strdup ("");
 		}
@@ -480,9 +481,9 @@ xbel_read_node (GbBookmarkSet *set, xmlNodePtr node)
                 g_free (title); 
 		xmlFree (url);
         } 
-	else if (!strcmp (node->name, "alias")) 
+	else if (!strcmp ((char*)node->name, "alias")) 
 	{
-		gchar *refstr = xmlGetProp (node, "ref");
+		gchar *refstr = (gchar*)xmlGetProp (node, (const xmlChar*)"ref");
 
 		item = GB_BOOKMARK (gb_alias_placeholder_new (set, refstr));
 		g_free (refstr);
@@ -491,7 +492,7 @@ xbel_read_node (GbBookmarkSet *set, xmlNodePtr node)
 
 		gb_alias_placeholder_set_create_toolbar (GB_ALIAS_PLACEHOLDER (item), md->toolbar);
         }
-	else if (!strcmp (node->name, "separator")) 
+	else if (!strcmp ((char*)node->name, "separator")) 
 	{
 		item  = GB_BOOKMARK (gb_separator_new (set));
 	}
@@ -502,8 +503,8 @@ xbel_read_node (GbBookmarkSet *set, xmlNodePtr node)
 
 	if (item) 
 	{
-		gchar *idstr = xmlGetProp (node, "id");
-		gchar *pixmap = xmlGetProp (node, "icon");
+		gchar *idstr = (char*)xmlGetProp (node, (const xmlChar*)"id");
+		gchar *pixmap = (char*)xmlGetProp (node, (const xmlChar*)"icon");
 		gchar *notes = get_child_value_string (node, "desc");
 		if (idstr) 
 		{
@@ -536,23 +537,23 @@ xbel_read_node (GbBookmarkSet *set, xmlNodePtr node)
 static GbXBELMetadata *
 xbel_read_metadata (xmlNodePtr node)
 {
-	xmlNodePtr info_node = get_child (node, "info");
+	xmlNodePtr info_node = get_child (node, (const xmlChar*)"info");
         if (info_node) 
 	{
                 /* Iterate over the metadata children */
                 for (info_node = info_node->children;
 		     info_node != NULL; info_node = info_node->next) 
 		{
-			if (!strcmp (info_node->name, "metadata")) 
+			if (!xmlStrcmp (info_node->name, (const xmlChar*)"metadata")) 
 			{
-				gchar *owner = xmlGetProp (info_node, "owner");
-				if (owner && !strcmp (owner, XBEL_GALEON_OWNER))
+				xmlChar* owner = xmlGetProp (info_node, (const xmlChar*)"owner");
+				if (owner && !xmlStrcmp (owner, (const xmlChar*)XBEL_GALEON_OWNER))
 				{
-					g_free (owner);
+					xmlFree (owner);
 					/* there can be only one metadata node */
 					return xbel_read_metadata_node (info_node);
 				}
-				g_free (owner);
+				xmlFree (owner);
 			}
 		}
 	}
@@ -703,7 +704,7 @@ xbel_save_root (GbBookmarkSet *set)
 	}
 	else
 	{
-		doc = xmlNewDoc ("1.0");
+		doc = xmlNewDoc ((const xmlChar*)"1.0");
 		gb_bookmark_set_set_xbel_doc (set, doc);
 	}
 
@@ -715,23 +716,24 @@ xbel_save_root (GbBookmarkSet *set)
 	}
 	else
 	{
-		newNode = xmlNewDocNode (doc, NULL, "xbel", NULL);
+		newNode = xmlNewDocNode (doc, NULL, (const xmlChar*)"xbel", NULL);
 		xmlDocSetRootElement (doc, newNode);
 		/* children xml nodes may have been freed, we must discard them :-( */
 		gb_bookmark_set_discard_xml_nodes (set);
 		gb_bookmark_set_xbel_node (GB_BOOKMARK (set->root), newNode);
 	}
 
-	xmlSetProp(newNode, "version", "1.0");
+	xmlSetProp(newNode, (const xmlChar*)"version", (const xmlChar*)"1.0");
 
 	/* I'm not sure if the following is OK */
 	if (xml_doc_get_dtd (doc) == NULL)
 	{
 		dtd = xmlNewDtd
-			(doc, "xbel", 
+			(doc, (const xmlChar*)"xbel", 
+                         (const xmlChar*)
 			 "+//IDN python.org//DTD XML Bookmark "
 			 "Exchange Language 1.0//EN//XML", 
-			 "http://www.python.org/topics/xml/dtds/xbel-1.0.dtd");
+			 (const xmlChar*)"http://www.python.org/topics/xml/dtds/xbel-1.0.dtd");
 		xmlAddPrevSibling (doc->children, (xmlNodePtr) dtd);
 	}
 
@@ -745,9 +747,10 @@ xbel_save_root (GbBookmarkSet *set)
 		GbXBELMetadata *md;
 		GbBookmark *child;
 
-		xmlSetProp (newNode, "folded", b->expanded ? "no" : "yes");
+		xmlSetProp (newNode, (const xmlChar*)"folded", 
+                            (const xmlChar*)(b->expanded ? "no" : "yes"));
 		
-		xml_node_update_text_child (newNode, NULL, "title", ((GbBookmark *) b)->name);
+		xml_node_update_text_child (newNode, NULL, (const xmlChar*)"title", (const xmlChar*)((GbBookmark *) b)->name);
 		md = xbel_save_common_data (newNode, (GbBookmark *) b);
 		
 		md->autofolder = GB_IS_AUTO_FOLDER (b);
@@ -797,7 +800,7 @@ xbel_save_node (xmlNodePtr parent_node, GbBookmarkSet *set, GbBookmark *b)
 		{
 			if (!b->xbel_node)
 			{
-				xmlNodePtr newNode = xmlNewChild (parent_node, NULL, "separator", NULL);
+				xmlNodePtr newNode = xmlNewChild (parent_node, NULL, (const xmlChar*)"separator", NULL);
 				gb_bookmark_set_xbel_node (b, newNode);
 			}
 			xbel_save_node_link_xml_node (b);
@@ -840,10 +843,12 @@ xbel_save_node_link_xml_node (GbBookmark *b)
 		
 		/* try to put it after title and info nodes, or at the beginning */
 
-		prev = get_child (GB_BOOKMARK (b->parent)->xbel_node, "info");
+		prev = get_child (GB_BOOKMARK (b->parent)->xbel_node, 
+                                  (const xmlChar*)"info");
 		if (!prev)
 		{
-			prev = get_child (GB_BOOKMARK (b->parent)->xbel_node, "title");
+			prev = get_child (GB_BOOKMARK (b->parent)->xbel_node, 
+                                          (const xmlChar*)"title");
 		}
 
 		if (prev)
@@ -899,12 +904,13 @@ xbel_save_site (xmlNodePtr parent_node, GbSite *b)
 	}
 	else
 	{
-		newNode = xmlNewChild (parent_node, NULL, "bookmark", NULL);
+		newNode = xmlNewChild (parent_node, NULL, (const xmlChar*)"bookmark", NULL);
 		gb_bookmark_set_xbel_node (GB_BOOKMARK (b), newNode);
 	}
 
-        xmlSetRawProp (newNode, "href", b->url);
-        xml_node_update_text_child (newNode, NULL, "title", ((GbBookmark *) b)->name);
+        xmlSetRawProp (newNode, (const xmlChar*)"href", (const xmlChar*)b->url);
+        xml_node_update_text_child (newNode, NULL,(const xmlChar*) "title",
+                                    (const xmlChar*)((GbBookmark *) b)->name);
 
 	md = xbel_save_common_data (newNode, (GbBookmark *) b);
 	if (GB_IS_SMART_SITE (b))
@@ -937,12 +943,13 @@ xbel_save_folder (xmlNodePtr parent_node, GbBookmarkSet *set, GbFolder *b)
 	}
 	else
 	{
-		newNode = xmlNewChild (parent_node, NULL, "folder", NULL);
+		newNode = xmlNewChild (parent_node, NULL, (const xmlChar*)"folder", NULL);
 		gb_bookmark_set_xbel_node (GB_BOOKMARK (b), newNode);
 	}
 
-        xmlSetProp (newNode, "folded", b->expanded ? "no" : "yes");
-        xml_node_update_text_child (newNode, NULL, "title", ((GbBookmark *) b)->name);
+        xmlSetProp (newNode, (const xmlChar*)"folded", (const xmlChar*)(b->expanded ? "no" : "yes"));
+        xml_node_update_text_child (newNode, NULL, (const xmlChar*)"title", 
+                                    (const xmlChar*)((GbBookmark *) b)->name);
 
 	md = xbel_save_common_data (newNode, GB_BOOKMARK (b));
 	
@@ -1004,11 +1011,11 @@ xbel_save_alias (xmlNodePtr parent_node, GbBookmark *b)
 	}
 	else
 	{
-		newNode = xmlNewChild (parent_node, NULL, "alias", NULL);
+		newNode = xmlNewChild (parent_node, NULL, (const xmlChar*)"alias", NULL);
 		gb_bookmark_set_xbel_node (GB_BOOKMARK (b), newNode);
 	}
 
-	xmlSetProp (newNode, "ref", real->id);
+	xmlSetProp (newNode, (const xmlChar*)"ref", (const xmlChar*)real->id);
 
 	md = xbel_save_common_data (newNode, b);
 	if (GB_IS_FOLDER (b)) 
@@ -1042,13 +1049,14 @@ xbel_save_alias_placeholder (xmlNodePtr parent_node, GbBookmark *b)
 	}
 	else
 	{
-		newNode = xmlNewChild (parent_node, NULL, "alias", NULL);
+		newNode = xmlNewChild (parent_node, NULL, (const xmlChar*)"alias", NULL);
 		gb_bookmark_set_xbel_node (GB_BOOKMARK (b), newNode);
 	}
 
 	if (GB_ALIAS_PLACEHOLDER (b)->alias_of_id)
 	{
-		xmlSetProp (newNode, "ref", GB_ALIAS_PLACEHOLDER (b)->alias_of_id);
+		xmlSetProp (newNode, (const xmlChar*)"ref",
+                            (const xmlChar*)GB_ALIAS_PLACEHOLDER (b)->alias_of_id);
 	}
 
 	md = xbel_save_common_data (newNode, b);
@@ -1078,15 +1086,16 @@ xbel_save_common_data (xmlNodePtr bookmark_node, GbBookmark *b)
 
 	if (b->id != NULL && !gb_bookmark_is_alias (b))
 	{
-		xmlSetProp (bookmark_node, "id", b->id);
+		xmlSetProp (bookmark_node, (const xmlChar*)"id", (const xmlChar*)b->id);
 	}
 	if (!gb_bookmark_is_alias (b) && sstrlen (b->notes) > 0) 
 	{
-		xml_node_update_text_child (bookmark_node, NULL, "desc", b->notes);
+		xml_node_update_text_child (bookmark_node, NULL,
+                             (const xmlChar*)"desc", (const xmlChar*)b->notes);
 	}
 	else
 	{
-		xml_node_remove_child (bookmark_node, "desc");
+		xml_node_remove_child (bookmark_node, (const xmlChar*)"desc");
 	}
 
 	if (sstrlen (b->nick) > 0)
@@ -1118,7 +1127,7 @@ xbel_save_galeon_metadata_find_node (xmlNodePtr node)
 	
         for (infoNode = node->children ; infoNode != NULL ; infoNode = infoNode->next)
 	{
-		if (!strcmp (infoNode->name, "info"))
+		if (!xmlStrcmp (infoNode->name, (const xmlChar*)"info"))
 		{
 			if (!first_info)
 			{
@@ -1127,23 +1136,23 @@ xbel_save_galeon_metadata_find_node (xmlNodePtr node)
 
 			for (metaNode = infoNode->children ; metaNode != NULL ; metaNode = metaNode->next)
 			{
-				if (!strcmp (metaNode->name, "metadata"))
+				if (!xmlStrcmp (metaNode->name, (const xmlChar*)"metadata"))
 				{
-					gchar *owner = xmlGetProp (metaNode, "owner");
-					if (owner && !strcmp (owner, XBEL_GALEON_OWNER))
+					xmlChar *owner = xmlGetProp (metaNode, (const xmlChar*)"owner");
+					if (owner && !xmlStrcmp (owner, (const xmlChar*)XBEL_GALEON_OWNER))
 					{
-						g_free (owner);
+						xmlFree (owner);
 						return metaNode;
 					}
-					g_free (owner);
+					xmlFree (owner);
 				}
 			}
 		}
 	}
 
-	infoNode = first_info ? first_info : xmlNewChild (node, NULL, "info", NULL);
-	metaNode = xmlNewChild (infoNode, NULL, "metadata", NULL);
-	xmlSetProp (metaNode, "owner", XBEL_GALEON_OWNER);
+	infoNode = first_info ? first_info : xmlNewChild (node, NULL, (const xmlChar*)"info", NULL);
+	metaNode = xmlNewChild (infoNode, NULL, (const xmlChar*)"metadata", NULL);
+	xmlSetProp (metaNode, (const xmlChar*)"owner", (const xmlChar*)XBEL_GALEON_OWNER);
 	
 	return metaNode;
 }
@@ -1158,7 +1167,7 @@ xbel_save_galeon_metadata_remove_metadata (xmlNodePtr node)
 	
         for (infoNode = node->children ; infoNode != NULL ; infoNode = infoNode->next)
 	{
-		if (!strcmp (infoNode->name, "info"))
+		if (!xmlStrcmp (infoNode->name, (const xmlChar*)"info"))
 		{
 			if (!first_info)
 			{
@@ -1167,16 +1176,16 @@ xbel_save_galeon_metadata_remove_metadata (xmlNodePtr node)
 
 			for (metaNode = infoNode->children ; metaNode != NULL ; metaNode = metaNode->next)
 			{
-				if (!strcmp (metaNode->name, "metadata"))
+				if (!xmlStrcmp (metaNode->name, (const xmlChar*)"metadata"))
 				{
-					gchar *owner = xmlGetProp (metaNode, "owner");
-					if (owner && !strcmp (owner, XBEL_GALEON_OWNER))
+					xmlChar *owner = xmlGetProp (metaNode, (const xmlChar*)"owner");
+					if (owner && !xmlStrcmp (owner, (const xmlChar*)XBEL_GALEON_OWNER))
 					{
-						g_free (owner);
+						xmlFree (owner);
 						found = metaNode;
 						break;
 					}
-					g_free (owner);
+					xmlFree (owner);
 				}
 			}
 		}
@@ -1223,128 +1232,128 @@ xbel_save_galeon_metadata (xmlNodePtr node, GbXBELMetadata *md)
                 /* export the nick name */
                 if (sstrlen (md->nick) > 0)
 		{
-                        xml_node_update_text_child (metaNode, NULL, "nick", md->nick);
+                        xml_node_update_text_child (metaNode, NULL, (const xmlChar*)"nick", (const xmlChar*)md->nick);
                 }
 		else
 		{
-                        xml_node_remove_child (metaNode, "nick");
+                        xml_node_remove_child (metaNode, (const xmlChar*)"nick");
                 }
 
                 /* pixmap path */
                 if (sstrlen (md->pixmap) > 0) 
 		{
-                        xml_node_update_text_child (metaNode, NULL, "pixmap", md->pixmap);
+                        xml_node_update_text_child (metaNode, NULL, (const xmlChar*)"pixmap", (const xmlChar*)md->pixmap);
                 }
 		else
 		{
-                        xml_node_remove_child (metaNode, "pixmap");
+                        xml_node_remove_child (metaNode, (const xmlChar*)"pixmap");
                 }
 
                 /* create a toolbar */
                 if (md->toolbar) 
 		{
-			xml_node_update_text_child (metaNode, NULL, "create_toolbar", "yes");
+			xml_node_update_text_child (metaNode, NULL, (const xmlChar*)"create_toolbar", (const xmlChar*)"yes");
                 }
 		else
 		{
-			xml_node_remove_child (metaNode, "create_toolbar");
+			xml_node_remove_child (metaNode, (const xmlChar*)"create_toolbar");
                 }
 
                 /* create a context menu */
                 if (md->context) 
 		{
-			xml_node_update_text_child (metaNode, NULL, "create_context", "yes");
+			xml_node_update_text_child (metaNode, NULL, (const xmlChar*)"create_context", (const xmlChar*)"yes");
                 }
 		else
 		{
-			xml_node_remove_child (metaNode, "create_context");
+			xml_node_remove_child (metaNode, (const xmlChar*)"create_context");
                 }
 
 		/* is this the default_folder? */
                 if (md->default_f)
 		{
-			xml_node_update_text_child (metaNode, NULL, "default_folder", "yes");
+			xml_node_update_text_child (metaNode, NULL, (const xmlChar*)"default_folder", (const xmlChar*)"yes");
                 }
 		else
 		{
-			xml_node_remove_child (metaNode, "default_folder");
+			xml_node_remove_child (metaNode, (const xmlChar*)"default_folder");
                 }
 
 		if (md->tb_style != 0) 
 		{
 			g_string_printf (s, "%d", md->tb_style);
-			xml_node_update_text_child (metaNode, NULL, "toolbar_style", s->str);
+			xml_node_update_text_child (metaNode, NULL, (const xmlChar*)"toolbar_style", (const xmlChar*)s->str);
 		}
 		else
 		{
-			xml_node_remove_child (metaNode, "toolbar_style");
+			xml_node_remove_child (metaNode, (const xmlChar*)"toolbar_style");
 		}
 
 		if (md->t_vis != 0)
 		{
 			g_string_printf (s, "%d", md->t_vis);
-			xml_node_update_text_child (metaNode, NULL, "time_visited", s->str);
+			xml_node_update_text_child (metaNode, NULL, (const xmlChar*)"time_visited", (const xmlChar*)s->str);
 		}
 		else
 		{
-			xml_node_remove_child (metaNode, "time_visited");
+			xml_node_remove_child (metaNode, (const xmlChar*)"time_visited");
 		}
 
 		if (md->t_mod != 0)
 		{
 			g_string_printf (s, "%d", md->t_mod);
-			xml_node_update_text_child (metaNode, NULL, "time_modified", s->str);
+			xml_node_update_text_child (metaNode, NULL, (const xmlChar*)"time_modified", (const xmlChar*)s->str);
 		}
 		else
 		{
-			xml_node_remove_child (metaNode, "time_modified");
+			xml_node_remove_child (metaNode, (const xmlChar*)"time_modified");
 		}
 
 		if (md->t_add != 0) 
 		{
 			g_string_printf (s, "%d", md->t_add);
-			xml_node_update_text_child (metaNode, NULL, "time_added", s->str);
+			xml_node_update_text_child (metaNode, NULL, (const xmlChar*)"time_added", (const xmlChar*)s->str);
 		}
 		else
 		{
-			xml_node_remove_child (metaNode, "time_added");
+			xml_node_remove_child (metaNode, (const xmlChar*)"time_added");
 		}
 
 		if (md->acc_mod != 0) 
 		{
 			g_string_printf (s, "%d", md->acc_mod);
-			xml_node_update_text_child (metaNode, NULL, "accel_mods", s->str);
+			xml_node_update_text_child (metaNode, NULL, (const xmlChar*)"accel_mods", (const xmlChar*)s->str);
 		}
 		else
 		{
-			xml_node_remove_child (metaNode, "accel_mods");
+			xml_node_remove_child (metaNode, (const xmlChar*)"accel_mods");
 		}
 
 		if (md->acc_key != 0) 
 		{
 			g_string_printf (s, "%d", md->acc_key);
-			xml_node_update_text_child (metaNode, NULL, "accel_key", s->str);
+			xml_node_update_text_child (metaNode, NULL, (const xmlChar*)"accel_key", (const xmlChar*)s->str);
 		}
 		else
 		{
-			xml_node_remove_child (metaNode, "accel_key");
+			xml_node_remove_child (metaNode, (const xmlChar*)"accel_key");
 		}
 
 		if (sstrlen (md->smarturl) > 0) 
 		{
 			gchar *smart_data = g_strdup_printf ("width=%d,folded=%d", md->entry_width, 
 							     md->entry_folded);
-			xml_node_update_text_child (metaNode, NULL, "smarturl",
-					 md->smarturl);
-			xml_node_update_text_child (metaNode, NULL, "smart_site_data",
-					 smart_data);
+			xml_node_update_text_child (metaNode, NULL, (const xmlChar*)"smarturl",
+					 (const xmlChar*)md->smarturl);
+			xml_node_update_text_child (metaNode, NULL, (const xmlChar*)"smart_site_data",
+					 (const xmlChar*)smart_data);
 			g_free (smart_data);
 
 		}
 		else
 		{
-			xml_node_remove_child (metaNode, "smarturl");
-			xml_node_remove_child (metaNode, "smart_site_data");
+			xml_node_remove_child (metaNode, (const xmlChar*)"smarturl");
+			xml_node_remove_child (metaNode, (const xmlChar*)"smart_site_data");
 		}
 
 		if (md->smart_site_history)
@@ -1362,89 +1371,89 @@ xbel_save_galeon_metadata (xmlNodePtr node, GbXBELMetadata *md)
 				}
 				g_free (item);
 			}
-			xml_node_update_text_child (metaNode, NULL, "smart_site_history",
-						    shist->str);
+			xml_node_update_text_child (metaNode, NULL, (const xmlChar*)"smart_site_history",
+						    (const xmlChar*)shist->str);
 			g_string_free (shist, TRUE);
 		}
 		else
 		{
-			xml_node_remove_child (metaNode, "smart_site_history");
+			xml_node_remove_child (metaNode, (const xmlChar*)"smart_site_history");
 		}
 
 		if (md->autofolder)
 		{
-			xml_node_update_text_child (metaNode, NULL, "autofolder", "yes");
+			xml_node_update_text_child (metaNode, NULL, (const xmlChar*)"autofolder", (const xmlChar*)"yes");
 			if (md->autobm_search_text)
 			{
-				xml_node_update_text_child (metaNode, NULL, "autobm_search_text", md->autobm_search_text);
+				xml_node_update_text_child (metaNode, NULL, (const xmlChar*)"autobm_search_text", (const xmlChar*)md->autobm_search_text);
 			}
 			else
 			{
-				xml_node_remove_child (metaNode, "autobm_search_text");
+				xml_node_remove_child (metaNode, (const xmlChar*)"autobm_search_text");
 			}
 
 			if (md->autobm_search_options)
 			{
-				xml_node_update_text_child (metaNode, NULL, "autobm_options", md->autobm_search_options);
+				xml_node_update_text_child (metaNode, NULL, (const xmlChar*)"autobm_options", (const xmlChar*)md->autobm_search_options);
 			}
 			else
 			{
-				xml_node_remove_child (metaNode, "autobm_options");
+				xml_node_remove_child (metaNode, (const xmlChar*)"autobm_options");
 			}
 		}
 		else
 		{
-			xml_node_remove_child (metaNode, "autofolder");
-			xml_node_remove_child (metaNode, "autobm_options");
-			xml_node_remove_child (metaNode, "autobm_search_text");
+			xml_node_remove_child (metaNode, (const xmlChar*)"autofolder");
+			xml_node_remove_child (metaNode, (const xmlChar*)"autobm_options");
+			xml_node_remove_child (metaNode, (const xmlChar*)"autobm_search_text");
 		}
 
 		if (md->vfolder)
 		{
-			xml_node_update_text_child (metaNode, NULL, "vfolder", "yes");
+			xml_node_update_text_child (metaNode, NULL, (const xmlChar*)"vfolder", (const xmlChar*)"yes");
 			if (md->vfolder_search_text)
 			{
-				xml_node_update_text_child (metaNode, NULL, "vfolder_search_text", md->vfolder_search_text);
+				xml_node_update_text_child (metaNode, NULL, (const xmlChar*)"vfolder_search_text", (const xmlChar*)md->vfolder_search_text);
 			}
 			else
 			{
-				xml_node_remove_child (metaNode, "vfolder_search_text");
+				xml_node_remove_child (metaNode, (const xmlChar*)"vfolder_search_text");
 			}
 
 			if (md->vfolder_search_options)
 			{
-				xml_node_update_text_child (metaNode, NULL, "vfolder_search_options", md->vfolder_search_options);
+				xml_node_update_text_child (metaNode, NULL, (const xmlChar*)"vfolder_search_options", (const xmlChar*)md->vfolder_search_options);
 			}
 			else
 			{
-				xml_node_remove_child (metaNode, "vfolder_search_options");
+				xml_node_remove_child (metaNode, (const xmlChar*)"vfolder_search_options");
 			}
 
 			if (md->vfolder_search_recently_created)
 			{
-				xml_node_update_text_child (metaNode, NULL, "vfolder_search_recently_created", md->vfolder_search_recently_created);
+				xml_node_update_text_child (metaNode, NULL, (const xmlChar*)"vfolder_search_recently_created", (const xmlChar*)md->vfolder_search_recently_created);
 			}
 			else
 			{
-				xml_node_remove_child (metaNode, "vfolder_search_recently_created");
+				xml_node_remove_child (metaNode, (const xmlChar*)"vfolder_search_recently_created");
 			}
 
 			if (md->vfolder_search_recently_visited)
 			{
-				xml_node_update_text_child (metaNode, NULL, "vfolder_search_recently_visited", md->vfolder_search_recently_visited);
+				xml_node_update_text_child (metaNode, NULL, (const xmlChar*)"vfolder_search_recently_visited", (const xmlChar*)md->vfolder_search_recently_visited);
 			}
 			else
 			{
-				xml_node_remove_child (metaNode, "vfolder_search_recently_visited");
+				xml_node_remove_child (metaNode, (const xmlChar*)"vfolder_search_recently_visited");
 			}
 		}
 		else
 		{
-			xml_node_remove_child (metaNode, "vfolder");
-			xml_node_remove_child (metaNode, "vfolder_search_text");
-			xml_node_remove_child (metaNode, "vfolder_search_options");
-			xml_node_remove_child (metaNode, "vfolder_search_recently_created");
-			xml_node_remove_child (metaNode, "vfolder_search_recently_visited");
+			xml_node_remove_child (metaNode, (const xmlChar*)"vfolder");
+			xml_node_remove_child (metaNode, (const xmlChar*)"vfolder_search_text");
+			xml_node_remove_child (metaNode, (const xmlChar*)"vfolder_search_options");
+			xml_node_remove_child (metaNode, (const xmlChar*)"vfolder_search_recently_created");
+			xml_node_remove_child (metaNode, (const xmlChar*)"vfolder_search_recently_visited");
 		}
 
 		if (md->version)
@@ -1455,10 +1464,10 @@ xbel_save_galeon_metadata (xmlNodePtr node, GbXBELMetadata *md)
 				/* shouldn't happen */
 				break;
 			case GB_FILE_FORMAT_VERSION_GALEON_1:
-				xml_node_update_text_child (metaNode, NULL, "galeon_xbel_version", "1");
+				xml_node_update_text_child (metaNode, NULL, (const xmlChar*)"galeon_xbel_version", (const xmlChar*)"1");
 				break;
 			case GB_FILE_FORMAT_VERSION_GALEON_2:
-				xml_node_update_text_child (metaNode, NULL, "galeon_xbel_version", "2");
+				xml_node_update_text_child (metaNode, NULL, (const xmlChar*)"galeon_xbel_version", (const xmlChar*)"2");
 				break;
 			}
 		}
@@ -1482,13 +1491,13 @@ xbel_save_galeon_metadata (xmlNodePtr node, GbXBELMetadata *md)
  * pointer to the first child which is called name.
  */
 static xmlNodePtr
-get_child (xmlNodePtr parent, const gchar *name)
+get_child (xmlNodePtr parent, const xmlChar*name)
 {
         xmlNodePtr child;
         g_return_val_if_fail (parent != NULL, NULL);
-        g_return_val_if_fail (sstrlen (name) > 0, NULL);
+        g_return_val_if_fail (strlen ((char*)name) > 0, NULL);
         for (child = parent->children ; child != NULL ; child = child->next)
-		if (!strcmp (child->name, name))
+		if (!xmlStrcmp (child->name, name))
                         return child;
         return NULL;
 }
@@ -1498,20 +1507,20 @@ get_child (xmlNodePtr parent, const gchar *name)
  * with the name name.
  */
 static gchar *
-get_child_value_string (xmlNodePtr parent, const gchar *name)
+get_child_value_string (xmlNodePtr parent, const char *name)
 {
-        xmlNodePtr child = get_child (parent, name);
+        xmlNodePtr child = get_child (parent, (const xmlChar*)name);
         if (child) {
-		gchar *v = xmlNodeGetContent (child);
+		xmlChar *v = xmlNodeGetContent (child);
 		gchar *ret = NULL;
-		if (v) ret = g_strdup (v);
+		if (v) ret = g_strdup ((char*)v);
 		xmlFree (v);
 		return ret;
 	} else return NULL;
 }
 
 static gboolean
-get_child_value_boolean (xmlNodePtr parent, const gchar *name)
+get_child_value_boolean (xmlNodePtr parent, const char *name)
 {
 	gchar *sval = get_child_value_string (parent, name);
 	gboolean ret = (sval 
@@ -1523,7 +1532,7 @@ get_child_value_boolean (xmlNodePtr parent, const gchar *name)
 }
 
 static glong
-get_child_value_long (xmlNodePtr parent, const gchar *name)
+get_child_value_long (xmlNodePtr parent, const char *name)
 {
 	gchar *sval = get_child_value_string (parent, name);
         glong ret = sval ? atol (sval) : 0;
@@ -1642,8 +1651,8 @@ xml_node_remove_child (xmlNodePtr parent, const xmlChar *name)
  * bookmarks file, this is used because libxml1 was broken ! (see bug 56487)
  */
 
-static gchar *
-escape_xml_prop (const gchar *text)
+static xmlChar*
+escape_xml_prop (const xmlChar*text)
 {
         GString *out = g_string_new (NULL);
         guchar c;
@@ -1656,9 +1665,9 @@ escape_xml_prop (const gchar *text)
                         g_string_append_c (out, c);
                 ++text;
         }
-        text = out->str;
+        text = (xmlChar*)out->str;
         g_string_free (out, FALSE); /* don't free char data, caller must */
-        return (gchar *)text;
+        return (xmlChar*)text;
 }
 
 /**
@@ -1670,7 +1679,7 @@ static xmlAttrPtr
 xmlSetRawProp (xmlNodePtr node, const xmlChar *name, const xmlChar *value)
 {
 	xmlAttrPtr attr;
-	gchar *escaped = escape_xml_prop (value);
+	xmlChar*escaped = escape_xml_prop (value);
 	attr = xmlSetProp (node, name, escaped);
 	g_free (escaped);
 	return attr;
@@ -1716,13 +1725,13 @@ static xmlChar *
 xmlGetRawProp (xmlNodePtr node, const xmlChar *name)
 {
 	xmlChar *value;
-	gchar *unescaped;
+	xmlChar *unescaped;
 	value = xmlGetProp (node, name);
 	if (value == NULL)
 	{
 		return NULL;
 	}
-	unescaped = unescape_hexed_string (value);
+	unescaped = (xmlChar*)unescape_hexed_string ((char*)value);
 	xmlFree (value);
 	return unescaped;
 }
