@@ -308,7 +308,7 @@ impl_show (GaleonDialog *dialog)
 				      HIG_ALERT_ERROR,
 				      _("There was a problem printing. "
 				        "No printers could be found."),
-				      _("Check whether the <tt>\"XPSERVERLIST\"</tt> envrionment "
+				      _("Check whether the <tt>\"XPSERVERLIST\"</tt> environment "
 				        "variable contains at least one valid Xprint server. "
 				        "For further information see http://xprint.mozdev.org "
 				        "or http://www.mozilla.org/projects/xprint/."),
