@@ -19,7 +19,15 @@
 #ifndef __GlobalHistory_h
 #define __GlobalHistory_h
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#ifdef HAVE_NSIGLOBALHISTORY3_H
+#include <nsIGlobalHistory3.h>
+#else
 #include <nsIGlobalHistory2.h>
+#endif
 
 #include "global-history.h"
 
@@ -28,7 +36,12 @@
 #define GALEON_GLOBALHISTORY_CID \
  { 0xbe0c42c1, 0x39d4, 0x4271, { 0xb7, 0x9e, 0xf7, 0xaa, 0x49, 0xeb, 0x6a, 0x15}}
 
-class MozGlobalHistory: public nsIGlobalHistory2
+class MozGlobalHistory:
+#ifdef HAVE_NSIGLOBALHISTORY3_H
+	public nsIGlobalHistory3
+#else
+	public nsIGlobalHistory2
+#endif
 {
 	public:
 		MozGlobalHistory ();
@@ -36,6 +49,9 @@ class MozGlobalHistory: public nsIGlobalHistory2
 
 		NS_DECL_ISUPPORTS
 		NS_DECL_NSIGLOBALHISTORY2
+#ifdef HAVE_NSIGLOBALHISTORY3_H
+		NS_DECL_NSIGLOBALHISTORY3
+#endif
 
 	private:
 		GlobalHistory *mGlobalHistory;
