@@ -63,6 +63,7 @@
 
 #include <glib/gi18n.h>
 
+#include "AutoJSContextStack.h"
 #include "GtkNSSKeyPairDialogs.h"
 
 GtkNSSKeyPairDialogs::GtkNSSKeyPairDialogs ()
@@ -193,6 +194,10 @@ GtkNSSKeyPairDialogs::DisplayGeneratingKeypairInfo (nsIInterfaceRequestor *ctx,
 	GtkWidget *dialog, *progress, *label, *vbox;
 	gint timeout_id;
 
+	nsresult rv;
+	AutoJSContextStack stack;
+	rv = stack.Init ();
+	if (NS_FAILED (rv)) return rv;
 
 	nsCOMPtr<nsIDOMWindow> parent = do_GetInterface (ctx);
 	GtkWidget *gparent = GaleonUtils::FindGtkParent (parent);
