@@ -33,6 +33,9 @@
 #include <nsICSSStyleSheet.h>
 #include <nsIScriptContext.h>
 #include <nsIHTMLDocument.h>
+#include <nsString.h>
+
+#include "MozillaPrivate.h"
 /***** END UNSAFE HEADERS ******/
 
 #include <nsIServiceManager.h>
@@ -47,7 +50,6 @@
 #include <nsIDOMNSDocument.h>
 #include <nsCOMPtr.h>
 
-#include "MozillaPrivate.h"
 #include "GaleonUtils.h"
 
 GList *
@@ -134,7 +136,7 @@ MozillaPrivate::LoadOverrideStyleSheet (nsIDocShell *aDocShell, nsIURI *aUri,
 #endif
 	NS_ENSURE_TRUE (doc, NS_ERROR_FAILURE);
 
-#if HAVE_NSIDOCUMENT_CSSLOADER
+#ifdef HAVE_NSIDOCUMENT_CSSLOADER
 	nsICSSLoader *loader = doc->CSSLoader();
 #else
 	nsICSSLoader *loader = doc->GetCSSLoader();
@@ -143,7 +145,11 @@ MozillaPrivate::LoadOverrideStyleSheet (nsIDocShell *aDocShell, nsIURI *aUri,
 
 	/* load sheet */
 	nsCOMPtr<nsICSSStyleSheet> sheet;
+#ifdef HAVE_NSICSSLOADER_LOADSHEETSYNC
+	rv = loader->LoadSheetSync(aUri, getter_AddRefs(sheet));
+#else
 	rv = loader->LoadAgentSheet(aUri, getter_AddRefs(sheet));
+#endif
 	NS_ENSURE_SUCCESS (rv, rv);
 
 	/* catch stylesheet stuff and apply by appending it as a override
