@@ -21,18 +21,11 @@
 #endif
 
 #include "galeon-window-bookmark-activated-proxy.h"
-#include "gul-gobject-misc.h"
 #include "bookmarks-util.h"
 
 /**
  * Private functions, only availble from this file
  */
-static void
-galeon_window_bookmark_activated_proxy_class_init 	(GaleonWindowBookmarkActivatedProxyClass *klass);
-
-static void
-galeon_window_bookmark_activated_proxy_init		(GaleonWindowBookmarkActivatedProxy *wbap);
-
 static void
 galeon_window_bookmark_activated_proxy_finalize_impl	(GObject *o);
 
@@ -46,21 +39,17 @@ void
 galeon_window_bookmark_activate (GaleonWindow *w, GbBookmarkEventActivated *ev);
 
 
-static gpointer g_object_class;
 
 /**
  * WindowBookmarkActivatedProxy object
  */
 
-MAKE_GET_TYPE (galeon_window_bookmark_activated_proxy, "GaleonWindowBookmarkActivatedProxy", 
-	       GaleonWindowBookmarkActivatedProxy, galeon_window_bookmark_activated_proxy_class_init, 
-	       galeon_window_bookmark_activated_proxy_init, G_TYPE_OBJECT);
+G_DEFINE_TYPE (GaleonWindowBookmarkActivatedProxy, galeon_window_bookmark_activated_proxy, G_TYPE_OBJECT);
 
 static void
 galeon_window_bookmark_activated_proxy_class_init (GaleonWindowBookmarkActivatedProxyClass *klass)
 {
 	G_OBJECT_CLASS (klass)->finalize = galeon_window_bookmark_activated_proxy_finalize_impl;
-	g_object_class = g_type_class_peek_parent (klass);
 }
 
 static void 
@@ -76,7 +65,7 @@ galeon_window_bookmark_activated_proxy_finalize_impl (GObject *o)
 
 	galeon_window_bookmark_activated_proxy_set_window (wbap, NULL);
 
-	G_OBJECT_CLASS (g_object_class)->finalize (o);
+	G_OBJECT_CLASS (galeon_window_bookmark_activated_proxy_parent_class)->finalize (o);
 
 }
 
